@@ -1,5 +1,7 @@
 '''
-@license: GNU Lesser General Public License v3.0 (see LICENSE)
+.. note::
+
+    license: GNU Lesser General Public License v3.0 (see LICENSE)
 
 Partial implementation of a OFX file writer.
 
@@ -7,10 +9,12 @@ This package is not intended to fully implement the OFX Spec. Its final purpose
 is the conversion from CSB43 (norma 43 del Consejo Superior Bancario). That is,
 only transaction response is (partially) implemented.
 
-References:
+.. seealso::
 
-- (http://www.ofx.net/)
+    References:
+
+    - (http://www.ofx.net/)
 '''
 
 from ofx_file import *
-from converter import *
\ No newline at end of file
+from converter import convertFromCsb, PAYMODES
\ No newline at end of file
